@@ -13,7 +13,11 @@ import {{appname}}.conf.config as cfg
 # http://stackoverflow.com/questions/446209/possible-values-from-sys-platform
 SPACES=90
 
-if __name__ == "__main__":
+def prep():
+    """
+        doing some preparations before running the tests
+
+    """
     migs_before=os.listdir(os.path.join("..", "migrations/versions"))
     # save the old sqlite db 
     dbname=cfg.database["sql"]["dbname"]
@@ -33,6 +37,21 @@ if __name__ == "__main__":
         backed_up_tinydb=True
     except:
         print(" no tinyDB so far")
+    
+    return {
+        "migs_before" : migs_before,
+        "dbname" : dbname,
+        "backup_path" : backup_path,
+        "backed_up_sqlite" : backed_up_sqlite,
+        "dbname_tiny" : dbname_tiny,
+        "backup_path_tiny" : backup_path_tiny,
+        "backed_up_tinydb" : backed_up_tinydb
+    }
+
+def run(conf):
+    """
+        calling the actual test set
+    """
     print(SPACES*"-")
     print(" running pow Tests on: " + sys.platform)
     print(" ... ")
@@ -46,18 +65,31 @@ if __name__ == "__main__":
     else:
         # OLD: ret = pytest.main(["--junitxml=result.xml", "pow_tests.py"])
         ret = pytest.main([
-            "--html=../views/testreport.html", "--self-contained-html", "pow_tests.py",
+            "--html=../views/testreport.html", "--self-contained-html",
             '-c', 'pytest.ini'
         ])
     
     print(" Failures: " +str(ret))
     print()
+    
+    print("  .. done.")
+    print(SPACES*"*")
+    print("  To see the test results run the server ad go to localhost:8080/testresults ")
+    print(SPACES*"*")
+    conf["testresult"] = ret
+    return conf
+
+
+def cleanup(conf):
+    """
+        cleaning up temp test stuff
+    """
     print(SPACES*"*")
     print("  cleaning up:")
     print(SPACES*"*")
     print("  .. removing the Test migrations")
     migs_after=os.listdir(os.path.join("..", "migrations/versions"))
-    del_migs=list(set(migs_after) - set(migs_before))
+    del_migs=list(set(migs_after) - set(conf["migs_before"]))
     print("    .. Migrationss to delete: {}".format(str(del_migs)))
     for elem in del_migs:
         try:
@@ -72,11 +104,11 @@ if __name__ == "__main__":
     print("  removing the Test DBs")
     print(SPACES*"-")
     try:
-        os.remove(dbname)
+        os.remove(conf["dbname"])
     except Exception as e:
         print(e)
     try:
-        os.remove(dbname_tiny)
+        os.remove(conf["dbname_tiny"])
     except Exception as e:
         print(e)
     print("  .. done.")
@@ -86,16 +118,16 @@ if __name__ == "__main__":
     print(SPACES*"-")
     print("  restoring the original DBs")
     print(SPACES*"-")
-    if backed_up_sqlite:
-        print("  .. I save your sqlite DB to: {}".format(backup_path))
-        print("    .. restoring it now ..... back to: {}".format(dbname))
-        shutil.copy(backup_path, dbname)
+    if conf["backed_up_sqlite"]:
+        print("  .. I save your sqlite DB to: {}".format(conf["backup_path"]))
+        print("    .. restoring it now ..... back to: {}".format(conf["dbname"]))
+        shutil.copy(conf["backup_path"], conf["dbname"])
     else:
         print("  .. You did not have a sqlite DB so nothing to restore")
-    if backed_up_tinydb:
-        print("  .. I save your tinyDB to: {}".format(backup_path_tiny))
-        print("    .. restoring it now ..... back to: {}".format(dbname_tiny))
-        shutil.copy(backup_path_tiny, dbname_tiny)
+    if conf["backed_up_tinydb"]:
+        print("  .. I save your tinyDB to: {}".format(conf["backup_path_tiny"]))
+        print("    .. restoring it now ..... back to: {}".format(conf["dbname_tiny"]))
+        shutil.copy(conf["backup_path_tiny"], conf["dbname_tiny"])
     else:
         print("  .. You did not have a tinyDB so nothing to restore")
     print(SPACES*"-")
@@ -114,7 +146,10 @@ if __name__ == "__main__":
     #    runner.run([os.path.join(curr_path,"result.xml"), os.path.join(curr_path,"../views/result.html")])
     #except Exception as e:
     #    print(e)
-    print("  .. done.")
-    print(SPACES*"*")
-    print("  To see the test results run the server ad go to localhost:8080/testresults ")
-    print(SPACES*"*")
+
+if __name__ == "__main__":
+    
+    conf = prep()
+    conf = run(conf)
+    conf = cleanup(conf)
+   
\ No newline at end of file
